@@ -6,7 +6,7 @@
 
 import time
 
-from lcd2usb import LCD, SMILE_SYMBOL, LCD2USBNotFound
+from lcd2usb import LCD, SMILE_SYMBOL
 
 
 BLINK_SMILE = bytearray([0x00, 0x00, 0x0a, 0x00, 0x11, 0x0e, 0x00, 0x00])
@@ -23,12 +23,10 @@ def blink(lcd):
 
 
 if __name__ == '__main__':
-    try:
-        lcd = LCD()
-    except LCD2USBNotFound, exc:
-        print exc
-        import sys
-        sys.exit(-1)
+    lcd = LCD.find_or_die()
     lcd.info()
-    print 'version:', '%s.%s' % lcd.version
-    blink(lcd)
+    print('version: %s.%s' % lcd.version)
+    try:
+        blink(lcd)
+    except KeyboardInterrupt:
+        pass
